function ll=CTMClikefun(tset,n0,ntrans_cat,Q)
%get the full log likelihood for a continuous-time homogeneous Markov model
%SYNTAX
%ll=CTMClikefun(tset,n0,ntrans_cat,Q)
%INPUTS
%tset is the set of times at which observations are taken , not necessarily
%equally spaced (assume there was an observation at t=0 as well)
%n0 is numbers observed in each state at time zero
%ntrans_cat is horizontally concatenated arrays of number of each transition observed at
%each time interval
%Q is the instantaneous rate matrix
%OUTPUTS
%ll is the full log likelihood (including the likelihood of the initial
%conditions under ML estimates, not assuming the system is at equilibrium)
%USES
%LVlikefun.m

%get ML estimates of initial state probs pO
p0=n0/sum(n0);

%get the P matrix for each time interval
tset=[0 tset];
Pset_cat=[];
for t=2:length(tset)
    P=expm(Q*(tset(t)-tset(t-1)));
    Pset_cat=[Pset_cat P];
end;

%call LVlikefun.m to get the full log likelihood
ll=LVlikefun(n0,ntrans_cat,p0,Pset_cat);