function [neglobs,p0_saturated,Pset_saturated,nparm_saturated]=LV_saturated_like(n0,ntrans_cat,tset);
%-log likelihood for 
%saturated model for a set of initial counts and transition counts:
%separate ML estimates of initial freqs and transition probabilities
%SYNTAX
%[neglobs,p0_saturated,Pset_saturated,nparm_saturated]=LV_saturated_like(n0,ntrans_cat,tset);
%INPUTS
%n0 is initial counts in each state
%ntrans_cat is concatenated counts of transitions: s rows (# states), s*t
%cols, where t is # time intervals
%tset is set of observation times (zero assumed to be the first one, not
%included)
%OUTPUTS
%neglobs is the -log likelihood for the saturated model
%p0_saturated is saturated (multinomial) estimates of initial freqs
%Pset_saturated is concatenated set of saturated transition probability
%estimates for each time interval (separate multinomial for each interval)
%nparm_saturated is number of parameters in saturated model
%USES
%LVlikefun.m

nt=length(tset);
s=length(n0);
p0_saturated=n0/sum(n0);%multinomial estimates of initial freqs
Pset_saturated=[];
for t=1:nt
    ntr=ntrans_cat(:,(t-1)*s+1:t*s);
    csum=sum(ntr);
    temp=csum(ones(s,1),:);
    P=ntr./temp;%multinomial estimates of transition probs for this time interval
    Pset_saturated=[Pset_saturated P];
end;
neglobs=-LVlikefun(n0,ntrans_cat,p0_saturated,Pset_saturated);%call log likelihood function with these estimates
nparm_saturated=s-1+s*(s-1)*nt;%s-1 for initial freqs, s*(s-1) for each transition matrix