function ll=LVlikefun(n0,ntrans_cat,p0,Pset_cat)
%get log likelihood for an LV-like model for sessile organisms
%SYNTAX
%ll=LVlikefun(n0,ntrans_cat,x0,Pset_cat)
%INPUTS
%n0 is the initial numbers in each state
%ntrans_cat is counts of transitions: concatenated matrices, s rows (where s is
%number of states), s*nt cols (where nt is number of time intervals): e.g.
%[ntrans{1} ntrans{2} ... ] from LVlike_sim.m
%p0 is probability of each state at time 0
%Pset_cat is a concatenated set of transition probabilities: same format as
%ntrans_cat
%OUTPUTS
%ll is the full log likelihood, including contributions from both initial
%conditions and transitions in each time interval

ind=logical(n0>0);%0*log(0)=0
ll=sum(n0(ind).*log(p0(ind)));%contribution from initial condition: not an ancillary statistic when transition probs depend on abundance

ind=logical(ntrans_cat>0);%0*log(0)=0
ll=ll+sum(ntrans_cat(ind).*log(Pset_cat(ind)));%contribution from transitions

