function [negl_dtav,Pav,p0_av,nparm_av]=get_dtav_like(n0,ntrans_cat,tset)
%log likelihood for a model with a time-averaged transition probability
%matrix, ignoring variation in time intervals
%SYNTAX
%[negl_dtav,Pav,p0_av,nparm_av]=get_dtav_like(n0,ntrans_cat,tset)
%INPUTS
%n0 is initial numbers in each state
%ntrans_cat is concatenated counts of transitions observed: s rows (where s
%is number of states), s*nt cols (where nt is number of time intervals):
%e.g. [ntrans(1) ntrans(2) ...] from LVlike_sim.m
%tset is the set of time intervals at which observations were taken (first
%observation assumed to be at zero)
%OUTPUTS
%negl_dtav is negative log likelihood
%Pav is discrete time-average transition probability matrix estimate
%p0_av is initial frequency estimates
%nparm_av is number of parameters
%USES
%LVlikefun.m

ntimes=length(tset);
nstates=size(ntrans_cat,1);
nav=zeros(nstates);
for t=1:ntimes
    sstart=(t-1)*nstates+1;
    send=sstart+nstates-1;
    nstep=ntrans_cat(:,sstart:send);%time-specific transition counts
    nav=nav+nstep;
end;

nsum=sum(nav);
nsum=nsum(ones(nstates,1),:);
Pav=nav./nsum;
Pav_set=zeros(size(ntrans_cat));
for t=1:ntimes
    sstart=(t-1)*nstates+1;
    send=sstart+nstates-1;
    Pav_set(:,sstart:send)=Pav;
end;
p0_av=n0/sum(n0);%multinomial estimates of initial freqs
negl_dtav=-LVlikefun(n0,ntrans_cat,p0_av,Pav_set);%call log likelihood function with these estimates
nparm_av=nstates-1+nstates*(nstates-1);%s-1 for initial freqs, s*(s-1) for the transition matrix
