function optresults_hom_randinit=gethomlike_randinit(n0,ntrans_cat,tset,fname,nreps,randseed,gethessian)
%fit homogeneous model from a series of random sets of initial conditions
%SYNTAX
%optresults_hom_randinit=gethomlike_randinit(n0,ntrans_cat,tset,fname,nreps,randseed,gethessian)
%INPUTS
%n0 is initial numbers in each state
%ntrans_cat is concatenated counts of transitions observed: s rows (where s
%is number of states), s*nt cols (where nt is number of time intervals):
%e.g. [ntrans(1) ntrans(2) ...] from LVlike_sim.m
%tset is the set of time intervals at which observations were taken (first
%observation assumed to be at zero)
%fname is the name of the file where the results are saved
%nreps is number of replicate sets of initial rate guesses to try
%randseed (optional) is the seed for the pseudorandom number generator
%(otherwise seed it by current time)
%gethessian (optional) is logical: if true, compute the hessian at the
%solution (default: don't compute)
%OUTPUTS
%optresults_hom_randinit is a structure with fields for each rep:
%negl is negative log likelihood
%p0_est is estimated initial frequencies
%Q_est is estimated rate matrix
%exitflag indicates exit condition of optimizer fmincon
%optoutput is a structure with information about the optimization
%grad is the gradient of the likelihood function at the solution
%hessian is the value of the Hessian (second derivative) matrix at the
%solution, for the transformed parameters used in unconstrained
%optimization
%timetaken is clock time used
%init_rates is initial rate estimates
%Also saved in the file fname with all the results (structure optresults contains most of
%them, with one element for each replicate)
%USES
%get_homogeneous_like.m
%setrandseed.m

if nargin>5 && ~isempty(randseed)%use specified seed
    setrandseed(randseed);
else%seed by time
    setrandseed();
end;

if nargin<7
    gethessian=false;
end;

s=length(n0);
%estimate from a series of random initial guesses
optresults_hom_randinit=struct('negl',{},'p0_est',{},'Q_est',{},'exitflag',{},'optoutput',{},'grad',{},'hessian',{},'timetaken',{},'init_rates',{});
r=1;
while r<=nreps
%for r=1:nreps
    disp(['fitting rep ',num2str(r)]);
    init_rates=rand(s*(s-1),1);%generate random initial guesses for interaction rates
    try
        [negl,p0_est,Q_est,exitflag,optoutput,grad,hessian,timetaken]=get_homogeneous_like(n0,ntrans_cat,tset,gethessian,init_rates);
        optresults_hom_randinit(r)=struct('negl',negl,'p0_est',p0_est,'Q_est',Q_est,'exitflag',exitflag,'optoutput',optoutput,'grad',grad,'hessian',hessian,'timetaken',timetaken,'init_rates',init_rates);%put all the results in a structure
        clear negl p0_est Q_est exitflag optoutput grad hessian timetaken init_rates;
        %save the results
        save(fname);
        r=r+1;
    catch
        disp('rep failed...trying again');
    end;
end;

